@@ -142,6 +142,8 @@ void AbstractAccount::registerApplication(const QString &appName, const QString
     };
     const QJsonDocument doc(obj);
 
+    fetchInstanceMetadata();
+
     post(regUrl, doc, false, this, [=](QNetworkReply *reply) {
         if (!reply->isFinished()) {
             qCDebug(TOKODON_LOG) << "not finished";
@@ -158,7 +160,6 @@ void AbstractAccount::registerApplication(const QString &appName, const QString
 
         if (isRegistered()) {
             Q_EMIT registered();
-            fetchInstanceMetadata();
         }
     });
 }
@@ -598,6 +599,17 @@ void AbstractAccount::invalidate()
     Q_EMIT invalidated();
 }
 
+void AbstractAccount::saveTimelinePosition(const QString &timeline, const QString &lastReadId)
+{
+    QUrl uri = apiUrl(QStringLiteral("/api/v1/markers"));
+
+    QUrlQuery urlQuery(uri);
+    urlQuery.addQueryItem(QStringLiteral("%1[last_read_id]").arg(timeline), lastReadId);
+    uri.setQuery(urlQuery);
+
+    post(uri, urlQuery, true, this, {});
+}
+
 void AbstractAccount::invalidatePost(Post *p)
 {
     Q_EMIT invalidatedPost(p);
@@ -623,6 +635,9 @@ void AbstractAccount::handleNotification(const QJsonDocument &doc)
     if (n->type() == Notification::FollowRequest) {
         m_followRequestCount++;
         Q_EMIT followRequestCountChanged();
+    } else {
+        m_unreadNotificationsCount++;
+        Q_EMIT unreadNotificationsCountChanged();
     }
 
     Q_EMIT notification(n);
@@ -633,6 +648,7 @@ void AbstractAccount::executeAction(Identity *identity, AccountAction accountAct
     const QHash<AccountAction, QString> accountActionMap = {
         {AccountAction::Follow, QStringLiteral("/follow")},
         {AccountAction::Unfollow, QStringLiteral("/unfollow")},
+        {AccountAction::RemoveFollower, QStringLiteral("/remove_from_followers")},
         {AccountAction::Block, QStringLiteral("/block")},
         {AccountAction::Unblock, QStringLiteral("/unblock")},
         {AccountAction::Mute, QStringLiteral("/mute")},
@@ -645,7 +661,7 @@ void AbstractAccount::executeAction(Identity *identity, AccountAction accountAct
     const auto apiCall = accountActionMap[accountAction];
 
     const auto accountId = identity->id();
-    const QString accountApiUrl = QStringLiteral("/api/v1/accounts/") + accountId + apiCall;
+    const QString accountApiUrl = QStringLiteral("/api/v1/accounts/%1%2").arg(accountId, apiCall);
     const QJsonDocument doc(extraArguments);
 
     post(apiUrl(accountApiUrl), doc, true, this, [=](QNetworkReply *reply) {
@@ -657,6 +673,7 @@ void AbstractAccount::executeAction(Identity *identity, AccountAction accountAct
             const QHash<AccountAction, QString> accountActionMap = {
                 {AccountAction::Follow, i18n("Could not follow account")},
                 {AccountAction::Unfollow, i18n("Could not unfollow account")},
+                {AccountAction::RemoveFollower, i18n("Could not remove account as your follower")},
                 {AccountAction::Block, i18n("Could not block account")},
                 {AccountAction::Unblock, i18n("Could not unblock account")},
                 {AccountAction::Mute, i18n("Could not mute account")},
@@ -673,7 +690,9 @@ void AbstractAccount::executeAction(Identity *identity, AccountAction accountAct
         // Returned relationship should have a value of true
         // under either the "following" or "requested" keys.
         auto relationship = identity->relationship();
-        relationship->updateFromJson(jsonObj);
+        if (relationship != nullptr) {
+            relationship->updateFromJson(jsonObj);
+        }
 
         Q_EMIT identity->relationshipChanged();
     });
@@ -684,6 +703,17 @@ int AbstractAccount::followRequestCount() const
     return m_followRequestCount;
 }
 
+void AbstractAccount::resetUnreadNotificationsCount()
+{
+    m_unreadNotificationsCount = 0;
+    Q_EMIT unreadNotificationsCountChanged();
+}
+
+int AbstractAccount::unreadNotificationsCount() const
+{
+    return m_unreadNotificationsCount;
+}
+
 void AbstractAccount::followAccount(Identity *identity, bool reblogs, bool notify)
 {
     executeAction(identity,
@@ -699,6 +729,11 @@ void AbstractAccount::unfollowAccount(Identity *identity)
     executeAction(identity, AccountAction::Unfollow);
 }
 
+void AbstractAccount::removeFollower(Identity *identity)
+{
+    executeAction(identity, AccountAction::RemoveFollower);
+}
+
 void AbstractAccount::blockAccount(Identity *identity)
 {
     executeAction(identity, AccountAction::Block);
@@ -845,4 +880,4 @@ QList<CustomEmoji> AbstractAccount::customEmojis() const
     return m_customEmojis;
 }
 
-#include "moc_abstractaccount.cpp"
\ No newline at end of file
+#include "moc_abstractaccount.cpp"
