@@ -26,12 +26,12 @@ public:
 
     explicit ListsModel(QObject *parent = nullptr);
 
-    bool loading() const;
+    [[nodiscard]] bool loading() const;
     void setLoading(bool loading);
 
-    QVariant data(const QModelIndex &index, int role) const override;
-    int rowCount(const QModelIndex &parent) const override;
-    QHash<int, QByteArray> roleNames() const override;
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role) const override;
+    [[nodiscard]] int rowCount(const QModelIndex &parent) const override;
+    [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
 
     void fillTimeline();
 
@@ -45,5 +45,5 @@ private:
 
     QList<List> m_lists;
     bool m_loading = false;
-    List fromSourceData(const QJsonObject &object) const;
+    [[nodiscard]] List fromSourceData(const QJsonObject &object) const;
 };
