@@ -36,7 +36,7 @@ void MockAccount::get(const QUrl &url,
         callback(reply);
         reply->seek(0);
     } else {
-        qWarning() << url << m_getReplies;
+        qWarning() << "Cannot find reply for " << url;
         if (errorCallback)
             errorCallback(nullptr);
     }
@@ -154,6 +154,10 @@ void MockAccount::checkForFollowRequests()
 {
 }
 
+void MockAccount::checkForUnreadNotifications()
+{
+}
+
 void MockAccount::registerPost(const QString &url, QNetworkReply *reply)
 {
     m_postReplies[apiUrl(url)] = reply;
@@ -230,8 +234,10 @@ void MockAccount::decreaseFollowRequests()
 void MockAccount::readNotificationFromFile(QLatin1String filename)
 {
     QFile statusExampleApi;
-    statusExampleApi.setFileName(QLatin1String(DATA_DIR) + QLatin1Char('/') + filename);
+    statusExampleApi.setFileName(QLatin1String(DATA_DIR "/%1").arg(filename));
     statusExampleApi.open(QIODevice::ReadOnly);
 
     handleNotification(QJsonDocument::fromJson(statusExampleApi.readAll()));
 }
+
+#include "moc_mockaccount.cpp"
