@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2022 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: GPL-3.0-or-later
-
+#pragma once
 #include "account/abstractaccount.h"
 
 class MockAccount : public AbstractAccount
@@ -51,6 +51,8 @@ public:
 
     void checkForFollowRequests() override;
 
+    void checkForUnreadNotifications() override;
+
     void registerPost(const QString &url, QNetworkReply *reply);
 
     void registerGet(const QUrl &url, QNetworkReply *reply);
