@@ -52,7 +52,7 @@ private Q_SLOTS:
     void testStreamUpdate()
     {
         QFile statusExampleApi;
-        statusExampleApi.setFileName(QLatin1String(DATA_DIR) + QLatin1Char('/') + "status.json"_L1);
+        statusExampleApi.setFileName(QLatin1String(DATA_DIR "/status.json"));
         statusExampleApi.open(QIODevice::ReadOnly);
 
         MainTimelineModel timelineModel;
@@ -65,13 +65,19 @@ private Q_SLOTS:
 
     void testFillTimelineMain()
     {
-        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/timelines/home")), new TestReply(QStringLiteral("statuses.json"), account));
+        QUrl markersUrl = account->apiUrl(QStringLiteral("/api/v1/markers"));
+        markersUrl.setQuery(QStringLiteral("timeline[]=home"));
+        account->registerGet(markersUrl, new TestReply(QStringLiteral("markers.json"), account));
         auto fetchMoreUrl = account->apiUrl(QStringLiteral("/api/v1/timelines/home"));
         fetchMoreUrl.setQuery(QUrlQuery{
             {QStringLiteral("max_id"), QStringLiteral("103270115826038975")},
         });
         account->registerGet(fetchMoreUrl, new TestReply(QStringLiteral("statuses.json"), account));
 
+        auto statusReply = new TestReply(QStringLiteral("statuses.json"), account);
+        statusReply->setRawHeader("Link", QStringLiteral("<%1>; rel=\"next\", <>; rel=\"prev\"").arg(fetchMoreUrl.toString()).toUtf8());
+        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/timelines/home")), statusReply);
+
         MainTimelineModel timelineModel;
         timelineModel.setName(QStringLiteral("home"));
 
@@ -130,7 +136,7 @@ private Q_SLOTS:
         timelineModel.setName(QStringLiteral("home"));
 
         QFile statusExampleApi;
-        statusExampleApi.setFileName(QLatin1String(DATA_DIR) + QLatin1Char('/') + "status-poll.json"_L1);
+        statusExampleApi.setFileName(QLatin1String(DATA_DIR "/status-poll.json"));
         statusExampleApi.open(QIODevice::ReadOnly);
         account->streamingEvent(AbstractAccount::StreamingEventType::UpdateEvent, statusExampleApi.readAll());
         QCOMPARE(timelineModel.rowCount({}), 6);
@@ -175,13 +181,16 @@ private Q_SLOTS:
 
     void testFillListTimeline()
     {
-        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/timelines/list/1")), new TestReply(QStringLiteral("statuses.json"), account));
         auto fetchMoreUrl = account->apiUrl(QStringLiteral("/api/v1/timelines/list/1"));
         fetchMoreUrl.setQuery(QUrlQuery{
             {QStringLiteral("max_id"), QStringLiteral("103270115826038975")},
         });
         account->registerGet(fetchMoreUrl, new TestReply(QStringLiteral("statuses.json"), account));
 
+        auto statusReply = new TestReply(QStringLiteral("statuses.json"), account);
+        statusReply->setRawHeader("Link", QStringLiteral("<%1>; rel=\"next\", <>; rel=\"prev\"").arg(fetchMoreUrl.toString()).toUtf8());
+        account->registerGet(account->apiUrl(QStringLiteral("/api/v1/timelines/list/1")), statusReply);
+
         MainTimelineModel timelineModel;
         timelineModel.setName(QStringLiteral("list"));
 
