@@ -116,21 +116,6 @@ int TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToEn
                 },
                 Qt::SingleShotConnection);
         }
-
-        // Ditto for boost identity
-        if (!post->boosted() && post->boostIdentity() == nullptr) {
-            connect(
-                post,
-                &Post::boostIdentity,
-                this,
-                [this, post] {
-                    const int row = m_timeline.indexOf(post);
-                    if (row != -1) {
-                        Q_EMIT dataChanged(index(row, 0), index(row, 0), {BoostAuthorIdentityRole});
-                    }
-                },
-                Qt::SingleShotConnection);
-        }
     }
 
     if (!m_timeline.isEmpty()) {
