@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carlschwan@kde.org>
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include "colorschemer.h"
+#include "utils/colorschemer.h"
 
 #include <KColorSchemeManager>
 
